@@ -11,6 +11,7 @@ import os
 
 # local imports
 from dotdrop.dictparser import DictParser
+from dotdrop.exceptions import UndefinedException
 
 
 class Cmd(DictParser):
@@ -32,17 +33,31 @@ class Cmd(DictParser):
         ret = 1
         action = self.action
         if templater:
-            action = templater.generate_string(self.action)
+            try:
+                action = templater.generate_string(self.action)
+            except UndefinedException as e:
+                err = 'bad {}: {}'.format(self.descr, e)
+                self.log.warn(err)
+                return False
             if debug:
-                self.log.dbg('{} \"{}\" -> \"{}\"'.format(self.descr,
-                                                          self.action,
-                                                          action))
+                self.log.dbg('{}:'.format(self.descr))
+                self.log.dbg('  - raw       \"{}\"'.format(self.action))
+                self.log.dbg('  - templated \"{}\"'.format(action))
         cmd = action
         args = []
         if self.args:
             args = self.args
             if templater:
-                args = [templater.generate_string(a) for a in args]
+                try:
+                    args = [templater.generate_string(a) for a in args]
+                except UndefinedException as e:
+                    err = 'bad arguments for {}: {}'.format(self.descr, e)
+                    self.log.warn(err)
+                    return False
+        if debug and args:
+            self.log.dbg('action args:')
+            for cnt, arg in enumerate(args):
+                self.log.dbg('\targs[{}]: {}'.format(cnt, arg))
         try:
             cmd = action.format(*args)
         except IndexError:
@@ -57,7 +72,11 @@ class Cmd(DictParser):
             return False
         if self.silent:
             self.log.sub('executing silent action \"{}\"'.format(self.key))
+            if debug:
+                self.log.dbg('action cmd silenced')
         else:
+            if debug:
+                self.log.dbg('action cmd: \"{}\"'.format(cmd))
             self.log.sub('executing \"{}\"'.format(cmd))
         try:
             ret = subprocess.call(cmd, shell=True)
@@ -74,25 +93,6 @@ class Cmd(DictParser):
     def __str__(self):
         return 'key:{} -> \"{}\"'.format(self.key, self.action)
 
-    def __repr__(self):
-        return 'cmd({})'.format(self.__str__())
-
-    def __eq__(self, other):
-        self_dict = {
-            k: v
-            for k, v in self.__dict__.items()
-            if k not in self.eq_ignore
-        }
-        other_dict = {
-            k: v
-            for k, v in other.__dict__.items()
-            if k not in self.eq_ignore
-        }
-        return self_dict == other_dict
-
-    def __hash__(self):
-        return hash(self.key) ^ hash(self.action)
-
 
 class Action(Cmd):
 
@@ -124,8 +124,8 @@ class Action(Cmd):
         return cls(key=key, **v)
 
     def __str__(self):
-        out = '{}: \"{}\" ({})'
-        return out.format(self.key, self.action, self.kind)
+        out = '{}: [{}] \"{}\"'
+        return out.format(self.key, self.kind, self.action)
 
     def __repr__(self):
         return 'action({})'.format(self.__str__())
