@@ -111,7 +111,7 @@ class Installer:
         if self.totemp:
             r, err, _ = self.install_to_temp(templater, self.totemp,
                                              src, dst, is_template=is_template,
-                                             chmod=chmod)
+                                             chmod=chmod, ignore=ignore)
             return self._log_install(r, err)
 
         isdir = os.path.isdir(src)
@@ -149,7 +149,8 @@ class Installer:
             else:
                 r, err = self._link_children(templater, src, dst,
                                              actionexec=actionexec,
-                                             is_template=is_template)
+                                             is_template=is_template,
+                                             ignore=ignore)
 
         if self.debug:
             self.log.dbg('before chmod: {} err:{}'.format(r, err))
@@ -185,7 +186,7 @@ class Installer:
         return self._log_install(r, err)
 
     def install_to_temp(self, templater, tmpdir, src, dst,
-                        is_template=True, chmod=None):
+                        is_template=True, chmod=None, ignore=[]):
         """
         install a dotfile to a tempdir
 
@@ -195,6 +196,7 @@ class Installer:
         @dst: dotfile destination path in the FS
         @is_template: this dotfile is a template
         @chmod: rights to apply if any
+        @ignore: patterns to ignore
 
         return
         - success, error-if-any, dotfile-installed-path
@@ -224,7 +226,7 @@ class Installer:
         ret, err = self.install(templater, src, tmpdst,
                                 LinkTypes.NOLINK,
                                 is_template=is_template,
-                                chmod=chmod)
+                                chmod=chmod, ignore=ignore)
         if self.debug:
             if ret:
                 self.log.dbg('tmp installed in {}'.format(tmpdst))
@@ -242,7 +244,8 @@ class Installer:
     # low level accessors for public methods
     ########################################################
 
-    def _link(self, templater, src, dst, actionexec=None, is_template=True):
+    def _link(self, templater, src, dst, actionexec=None,
+              is_template=True):
         """
         install link:link
 
@@ -268,7 +271,7 @@ class Installer:
         return r, err
 
     def _link_children(self, templater, src, dst,
-                       actionexec=None, is_template=True):
+                       actionexec=None, is_template=True, ignore=[]):
         """
         install link:link_children
 
@@ -309,6 +312,13 @@ class Installer:
             subsrc = srcs[i]
             subdst = dsts[i]
 
+            if utils.must_ignore([subsrc, subdst], ignore, debug=self.debug):
+                if self.debug:
+                    self.log.dbg(
+                        'ignoring install of {} to {}'.format(src, dst),
+                    )
+                continue
+
             if self.debug:
                 self.log.dbg('symlink child {} to {}'.format(subsrc, subdst))
 
