@@ -43,7 +43,7 @@ OPT_LINK = {
     LinkTypes.LINK.name.lower(): LinkTypes.LINK,
     LinkTypes.LINK_CHILDREN.name.lower(): LinkTypes.LINK_CHILDREN}
 
-BANNER = """     _       _      _
+BANNER = r"""     _       _      _
   __| | ___ | |_ __| |_ __ ___  _ __
  / _` |/ _ \| __/ _` | '__/ _ \| '_ |
  \__,_|\___/ \__\__,_|_|  \___/| .__/  v{}
@@ -56,10 +56,10 @@ Usage:
   dotdrop install   [-VbtfndDa] [-c <path>] [-p <profile>]
                                 [-w <nb>] [<key>...]
   dotdrop import    [-Vbdfm]    [-c <path>] [-p <profile>] [-s <path>]
-                                [-l <link>] <path>...
-  dotdrop compare   [-LVb]      [-c <path>] [-p <profile>]
+                                [-l <link>] [-i <pattern>...] <path>...
+  dotdrop compare   [-LVbz]     [-c <path>] [-p <profile>]
                                 [-w <nb>] [-C <file>...] [-i <pattern>...]
-  dotdrop update    [-VbfdkP]   [-c <path>] [-p <profile>]
+  dotdrop update    [-VbfdkPz]  [-c <path>] [-p <profile>]
                                 [-w <nb>] [-i <pattern>...] [<path>...]
   dotdrop remove    [-Vbfdk]    [-c <path>] [-p <profile>] [<path>...]
   dotdrop files     [-VbTG]     [-c <path>] [-p <profile>]
@@ -73,6 +73,7 @@ Options:
   -b --no-banner          Do not display the banner.
   -c --cfg=<path>         Path to the config.
   -C --file=<path>        Path of dotfile to compare.
+  -z --ignore-missing     Ignore files in installed folders that are missing.
   -d --dry                Dry run.
   -D --showdiff           Show a diff before overwriting.
   -f --force              Do not ask user confirmation for anything.
@@ -264,11 +265,17 @@ class Options(AttrMonitor):
         self.compare_ignore.append('*{}'.format(self.install_backup_suffix))
         self.compare_ignore = uniq_list(self.compare_ignore)
         self.compare_fileonly = self.args['--file-only']
+        self.ignore_missing_in_dotdrop = self.ignore_missing_in_dotdrop or \
+            self.args['--ignore-missing']
 
         # "import" specifics
         self.import_path = self.args['<path>']
         self.import_as = self.args['--as']
         self.import_mode = self.args['--preserve-mode']
+        self.import_ignore = self.args['--ignore']
+        self.import_ignore.extend(self.impignore)
+        self.import_ignore.append('*{}'.format(self.install_backup_suffix))
+        self.import_ignore = uniq_list(self.import_ignore)
 
         # "update" specifics
         self.update_path = self.args['<path>']
